pub struct MeshInstance {
pub name: Option<String>,
pub mesh: Mesh,
pub transform: Option<Transform>,
}Available on crate feature
scene only.Expand description
One mesh instance attached to a scene node.
The mesh data is owned by the instance for now; transform is the optional
local transform applied to this specific instance when it cannot be folded
into the containing node.
Fields
name: Option<String>Optional instance name.
mesh: MeshMesh data for this instance.
transform: Option<Transform>Optional local transform for this instance.