pub struct FbxAnimSampler {
pub input: Vec<f32>,
pub output: Vec<f32>,
pub interpolation: FbxAnimInterpolation,
pub in_tangents: Option<Vec<f32>>,
pub out_tangents: Option<Vec<f32>>,
}Available on crate features
fbx-reader or fbx-writer only.Expand description
One animation sampler (a flat TRS or morph-weight track).
Fields
input: Vec<f32>Strictly increasing keyframe times in seconds.
output: Vec<f32>Flattened keyframe values, component_count() values per input entry.
interpolation: FbxAnimInterpolationCoarse interpolation mode.
in_tangents: Option<Vec<f32>>Flattened incoming cubic tangents in output units per second.
out_tangents: Option<Vec<f32>>Flattened outgoing cubic tangents in output units per second.