FbxSkinCluster

Struct FbxSkinCluster 

pub struct FbxSkinCluster {
    pub joint_node_id: FbxNodeId,
    pub control_point_indices: Vec<u32>,
    pub weights: Vec<f32>,
    pub mesh_bind_transform: FbxTransform,
    pub joint_bind_transform: FbxTransform,
    pub armature_bind_transform: Option<FbxTransform>,
}
Available on crate features fbx-reader or fbx-writer only.
All influences from one joint onto a mesh’s control points.

Fields

joint_node_id: FbxNodeId

Joint Model that owns this cluster.

control_point_indices: Vec<u32>

Affected mesh control-point indices.

weights: Vec<f32>

Weight for each entry in Self::control_point_indices.

mesh_bind_transform: FbxTransform

Mesh global transform captured in the bind pose (Transform).

joint_bind_transform: FbxTransform

Joint global transform captured in the bind pose (TransformLink).

armature_bind_transform: Option<FbxTransform>

Armature global transform captured in the bind pose (TransformAssociateModel), when supplied by the source.